@@ -1,6 +1,6 @@
 /*
  * SPDX-FileCopyrightText: 2020-2021 Han Young <hanyoung@protonmail.com>
- * SPDX-FileCopyrightText: 2020 Devin Lin <espidev@gmail.com>
+ * SPDX-FileCopyrightText: 2020-2021 Devin Lin <espidev@gmail.com>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -236,11 +236,13 @@ DailyWeatherForecast::operator+=(const HourlyWeatherForecast &forecast)
         setWeatherIcon(forecast.weatherIcon());
         d->isValid = false;
     }
+    
     if (date().daysTo(forecast.date().date()) == 0) {
         // set description and icon if it is higher ranked
-        if (rank[forecast.neutralWeatherIcon()] >= rank[weatherIcon()]) {
+        if (self()->weatherIconPriorityRank(forecast.neutralWeatherIcon()) >= 
+            self()->weatherIconPriorityRank(weatherIcon())) {
             setWeatherDescription(
-                apiDescMap[forecast.symbolCode() + QStringLiteral("_neutral")]
+                self()->resolveAPIWeatherDesc(forecast.symbolCode() + QStringLiteral("_neutral"))
                     .desc);
             setWeatherIcon(forecast.neutralWeatherIcon());
         }
